<?php

/**
 * Listing Types - Type 1
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if( !class_exists( 'Multifox_Woo_Listing_Type_Type1' ) ) {

    class Multifox_Woo_Listing_Type_Type1 {

        private static $_instance = null;

        private $type_slug;

        private $type_name;

        public static function instance() {

            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;

        }

        function __construct() {

            /* Initialize Type */
                $this->type_slug = 'type1';
                $this->type_name = esc_html__('Type 1', 'multifox');

            /* Backend Render */
                $this->render_backend();

        }

        /*
        Module Paths
        */

            function module_dir_path() {

                if( multifox_is_file_in_theme( __FILE__ ) ) {
                    return MULTIFOX_MODULE_DIR . '/woocommerce/listings/types/';
                } else {
                    return trailingslashit( plugin_dir_path( __FILE__ ) );
                }

            }

            function module_dir_url() {

                if( multifox_is_file_in_theme( __FILE__ ) ) {
                    return MULTIFOX_MODULE_URI . '/woocommerce/listings/types/';
                } else {
                    return trailingslashit( plugin_dir_url( __FILE__ ) );
                }

            }

        /*
        Backend Render
        */
            function render_backend() {

                /* Custom Product Templates - Options */
                    add_filter( 'multifox_woo_default_product_templates', array( $this, 'woo_default_product_templates'), 10, 1 );

            }

        /*
        Custom Product Templates - Options
        */
            function woo_default_product_templates( $templates ) {

                $type_options = array_merge (
                    array( 'product-template-id' => $this->type_name ),
                    $this->set_type_options()
                );

                $default_template = array (
                    'id'              => 'multifox-woo-product-style-template-'.$this->type_slug,
                    'type'            => 'group',
                    'multifox_default_type' => true,
                    'title'           => sprintf( esc_html__( 'Product Templates - %1$s', 'multifox' ), $this->type_name ),
                    'button_title'    => esc_html__('Add New', 'multifox'),
                    'accordion_title' => esc_html__('Add New Template', 'multifox'),
                    'fields'          => multifox_woo_listing_fw_template_settings()->woo_get_options_params( $type_options, 'default' ),
                    'default'         => array ( 0 => $type_options )
                );

                array_push( $templates, $default_template );

                return $templates;

            }

        /*
        Set Type Options
        */
            function set_type_options() {

                $type_options = array ();

                $type_options['product-display-type'] = 'grid';
                $type_options['product-display-type-list-option'] = 'left-thumb';

                $type_options['product-style']                        = 'product-style-title-eg-highlighter';
                $type_options['product-hover-style']                  = 'product-hover-fade-skinborder';
                $type_options['product-hover-secondary-image-effect'] = 'product-hover-secimage-pushleft';
                $type_options['product-content-hover-effect']         = 'product-content-hover-slideright';
                $type_options['product-thumb-content']          = array (
                    'enabled'      => array (
                        'title'          => esc_html__('Title', 'multifox'),
                        'category'       => esc_html__('Category', 'multifox'),
                        'price'          => esc_html__('Price', 'multifox')
                    ),
                    'disabled'     => array (
                        'button_element' => esc_html__('Button Element', 'multifox'),
                        'icons_group'    => esc_html__('Icons Group', 'multifox'),
                        'excerpt'        => esc_html__('Excerpt', 'multifox'),
                        'rating'         => esc_html__('Rating', 'multifox'),
                        'countdown'      => esc_html__('Count Down', 'multifox'),
                        'separator'      => esc_html__('Separator', 'multifox'),
                        'element_group'  => esc_html__('Element Group', 'multifox'),
                        'swatches'       => esc_html__('Swatches', 'multifox')
                    )
                );

                $type_options['product-content-enable']         = '1';
                $type_options['product-content-content']        = array (
                    'enabled'      => array(
                        'title'          => esc_html__('Title', 'multifox'),
                        'price'          => esc_html__('Price', 'multifox')
                    ),
                    'disabled'     => array(
                        'category'       => esc_html__('Category', 'multifox'),
                        'button_element' => esc_html__('Button Element', 'multifox'),
                        'icons_group'    => esc_html__('Icons Group', 'multifox'),
                        'excerpt'        => esc_html__('Excerpt', 'multifox'),
                        'rating'         => esc_html__('Rating', 'multifox'),
                        'countdown'      => esc_html__('Count Down', 'multifox'),
                        'separator'      => esc_html__('Separator', 'multifox'),
                        'element_group'  => esc_html__('Element Group', 'multifox'),
                        'swatches'       => esc_html__('Swatches', 'multifox'),
                        'product_notes'  => esc_html__('Product Notes', 'multifox')
                    )
                );
                $type_options['product-content-element-group']  = array (
                    'enabled'      => array(
                        'cart'           => esc_html__('Cart', 'multifox'),
                        'category'       => esc_html__('Category', 'multifox')
                    ),
                    'disabled'     => array(
                        'title'          => esc_html__('Title', 'multifox'),
                        'price'          => esc_html__('Price', 'multifox'),
                        'wishlist'       => esc_html__('Wishlist', 'multifox'),
                        'compare'        => esc_html__('Compare', 'multifox'),
                        'quickview'      => esc_html__('Quick View', 'multifox'),
                        'button_element' => esc_html__('Button Element', 'multifox'),
                        'icons_group'    => esc_html__('Icons Group', 'multifox'),
                        'excerpt'        => esc_html__('Excerpt', 'multifox'),
                        'rating'         => esc_html__('Rating', 'multifox'),
                        'separator'      => esc_html__('Separator', 'multifox'),
                        'swatches'       => esc_html__('Swatches', 'multifox')
                    )
                );
                $type_options['product-display-type'] = 'list';

                return $type_options;


            }

        /*
        Frontend Render
        */
            function render_frontend() {

                $non_archive_listing = wc_get_loop_prop('non_archive_listing');

                if( $non_archive_listing ) {

                    /* Types CSS */
                        add_filter( 'multifox_woo_non_archive_css', array( $this, 'woo_listings_css_load'), 10, 1 );

                } else {

                    /* Types CSS */
                        add_filter( 'multifox_woo_archive_css', array( $this, 'woo_listings_css_load'), 10, 1 );

                }

            }

        /*
        Types CSS
        */
            function woo_listings_css_load( $css ) {

                $css .= $this->load_type_css();
                $css .= $this->load_type_skin_css();

                return $css;

            }

            // Type Main CSS
            function load_type_css() {

                $css = '';

                $css_file_path = $this->module_dir_path() . 'assets/css/'.$this->type_slug.'.css';

                if( file_exists ( $css_file_path ) ) {

                    ob_start();
                    include( $css_file_path );
                    $css .= "\n\n".ob_get_clean();

                }

                return $css;

            }

            // Type Skin CSS
            function load_type_skin_css() {

                $css = '';
                return $css;

            }


        /*
        For Non Archive Listing
        */
            function for_non_archive_listing() {

                /* Load Other Modules */

                    $sub_modules = array (
                        'includes' => 'listings/includes/index'
                    );

                    if( is_array( $sub_modules ) && !empty( $sub_modules ) ) {
                        foreach( $sub_modules as $sub_module ) {

                            if( $file_content = multifox_woo_locate_file( $sub_module ) ) {
                                include_once $file_content;
                            }

                        }
                    }


                /* Assets Load */

                    // CSS

                        wp_register_style( 'multifox-woo-non-archive', '', array (), MULTIFOX_THEME_VERSION, 'all' );
                        wp_enqueue_style( 'multifox-woo-non-archive' );

                        $css = '';

                        // Load common styles
                        if( !is_shop() && !is_product_category() && !is_product_tag() && !is_product() && !is_cart() && !is_checkout() ) {

                            $css_file_path = MULTIFOX_MODULE_DIR . '/woocommerce/assets/css/common.css';

                            if( file_exists ( $css_file_path ) ) {

                                ob_start();
                                include( $css_file_path );
                                $css .= "\n\n".ob_get_clean();

                            }

                            $css_file_path = MULTIFOX_MODULE_DIR . '/woocommerce/single/assets/css/common.css';

                            if( file_exists ( $css_file_path ) ) {

                                ob_start();
                                include( $css_file_path );
                                $css .= "\n\n".ob_get_clean();

                            }

                        }

                        $css = apply_filters( 'multifox_woo_non_archive_css', $css );

                        if( !empty($css) ) {
                            wp_add_inline_style( 'multifox-woo-non-archive', $css );
                        }

                    // JS

                        wp_register_script( 'multifox-woo-non-archive', '', array ('jquery'), false, true );
                        wp_enqueue_script( 'multifox-woo-non-archive' );

                        $js = '';

                        // Load common js
                        if( !is_shop() && !is_product_category() && !is_product_tag() && !is_product() && !is_cart() && !is_checkout() ) {
                            $js_file_path = MULTIFOX_MODULE_DIR . '/woocommerce/assets/js/common.js';

                            if( file_exists ( $js_file_path ) ) {

                                ob_start();
                                include( $js_file_path );
                                $js .= "\n\n".ob_get_clean();

                            }
                        }

                        $js = apply_filters( 'multifox_woo_non_archive_js', $js );

                        if( !empty($js) ) {
                            wp_add_inline_script( 'multifox-woo-non-archive', $js );
                        }

            }

    }

}

if( !function_exists('multifox_woo_listing_type_type1') ) {
	function multifox_woo_listing_type_type1() {
		return Multifox_Woo_Listing_Type_Type1::instance();
	}
}

multifox_woo_listing_type_type1();